@@ -115,7 +115,9 @@ void Export_pyste_src_Image()
         .def("floodFillColor", (void (Magick::Image::*)(const Magick::Geometry&, const Magick::Color&) )&Magick::Image::floodFillColor)
         .def("floodFillColor", (void (Magick::Image::*)(const ::ssize_t, const ::ssize_t, const Magick::Color&, const Magick::Color&) )&Magick::Image::floodFillColor)
         .def("floodFillColor", (void (Magick::Image::*)(const Magick::Geometry&, const Magick::Color&, const Magick::Color&) )&Magick::Image::floodFillColor)
-        .def("floodFillOpacity", &Magick::Image::floodFillOpacity)
+        .def("floodFillOpacity", (void (Magick::Image::*)(const ::ssize_t, const ::ssize_t, const unsigned int, const bool) ) &Magick::Image::floodFillOpacity)
+        .def("floodFillOpacity", (void (Magick::Image::*)(const ::ssize_t, const ::ssize_t, const unsigned int, const Magick::PaintMethod) ) &Magick::Image::floodFillOpacity)
+        .def("floodFillOpacity", (void (Magick::Image::*)(const ::ssize_t, const ::ssize_t, const unsigned int, const Magick::Color&, const bool) ) &Magick::Image::floodFillOpacity)
         .def("floodFillTexture", (void (Magick::Image::*)(const ::ssize_t, const ::ssize_t, const Magick::Image&) )&Magick::Image::floodFillTexture)
         .def("floodFillTexture", (void (Magick::Image::*)(const Magick::Geometry&, const Magick::Image&) )&Magick::Image::floodFillTexture)
         .def("floodFillTexture", (void (Magick::Image::*)(const ::ssize_t, const ::ssize_t, const Magick::Image&, const Magick::Color&) )&Magick::Image::floodFillTexture)
@@ -189,13 +191,13 @@ void Export_pyste_src_Image()
         .def("adjoin", (void (Magick::Image::*)(const bool) )&Magick::Image::adjoin)
         .def("adjoin", (bool (Magick::Image::*)() const)&Magick::Image::adjoin)
         .def("antiAlias", (void (Magick::Image::*)(const bool) )&Magick::Image::antiAlias)
-        .def("antiAlias", (bool (Magick::Image::*)() )&Magick::Image::antiAlias)
+        .def("antiAlias", (bool (Magick::Image::*)() const)&Magick::Image::antiAlias)
         .def("animationDelay", (void (Magick::Image::*)(const size_t) )&Magick::Image::animationDelay)
         .def("animationDelay", (size_t (Magick::Image::*)() const)&Magick::Image::animationDelay)
         .def("animationIterations", (void (Magick::Image::*)(const size_t) )&Magick::Image::animationIterations)
         .def("animationIterations", (size_t (Magick::Image::*)() const)&Magick::Image::animationIterations)
         .def("attribute", (void (Magick::Image::*)(const std::string, const std::string) )&Magick::Image::attribute)
-        .def("attribute", (std::string (Magick::Image::*)(const std::string) )&Magick::Image::attribute)
+        .def("attribute", (std::string (Magick::Image::*)(const std::string) const )&Magick::Image::attribute)
         .def("backgroundColor", (void (Magick::Image::*)(const Magick::Color&) )&Magick::Image::backgroundColor)
         .def("backgroundColor", (Magick::Color (Magick::Image::*)() const)&Magick::Image::backgroundColor)
         .def("backgroundTexture", (void (Magick::Image::*)(const std::string&) )&Magick::Image::backgroundTexture)
@@ -226,7 +228,7 @@ void Export_pyste_src_Image()
         .def("colorMap", (void (Magick::Image::*)(const size_t, const Magick::Color&) )&Magick::Image::colorMap)
         .def("colorMap", (Magick::Color (Magick::Image::*)(const size_t) const)&Magick::Image::colorMap)
         .def("colorMapSize", (void (Magick::Image::*)(const size_t) )&Magick::Image::colorMapSize)
-        .def("colorMapSize", (size_t (Magick::Image::*)() )&Magick::Image::colorMapSize)
+        .def("colorMapSize", (size_t (Magick::Image::*)() const)&Magick::Image::colorMapSize)
         .def("colorSpace", (void (Magick::Image::*)(const MagickCore::ColorspaceType) )&Magick::Image::colorSpace)
         .def("colorSpace", (MagickCore::ColorspaceType (Magick::Image::*)() const)&Magick::Image::colorSpace)
         .def("columns", &Magick::Image::columns)
@@ -369,8 +371,6 @@ void Export_pyste_src_Image()
         .def("writePixels", &Magick::Image::writePixels)
         .def("modifyImage", &Magick::Image::modifyImage)
         .def("throwImageException", &Magick::Image::throwImageException)
-        .def("registerId", &Magick::Image::registerId)
-        .def("unregisterId", &Magick::Image::unregisterId)
         .staticmethod("cacheThreshold")
         .def( self == self )
         .def( self != self )
